@@ -66,6 +66,7 @@ fn apply_operator(left: f64, op: Operator, right: f64) -> Result<f64, EvalError>
             }
             left / right
         }
+        Operator::Pow => left.powf(right),
     };
     Ok(eval)
 }
@@ -95,5 +96,18 @@ mod tests {
             eval_func_call(&fc!("sqrt", 10., 20.)),
             Err(EvalError::arg_count_does_not_match("sqrt", 1, 2))
         );
+
+        assert_eq!(eval_func_call(&fc!("pow", 2, 3)), Ok(8.));
+        assert_eq!(
+            eval_func_call(&fc!("pow", 2)),
+            Err(EvalError::arg_count_does_not_match("pow", 2, 1))
+        );
+
+        assert_eq!(eval_func_call(&fc!("abs", -3.)), Ok(3.));
+        assert_eq!(eval_func_call(&fc!("abs", 3.)), Ok(3.));
+        assert_eq!(
+            eval_func_call(&fc!("abs", 2, 2)),
+            Err(EvalError::arg_count_does_not_match("abs", 1, 2))
+        );
     }
 }
